==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/neptune/kotlin/inputs/ClusterParameterGroupParameterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.neptune.kotlin.inputs

import com.pulumi.aws.neptune.inputs.ClusterParameterGroupParameterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property applyMethod Valid values are `immediate` and `pending-reboot`. Defaults to `pending-reboot`.
 * @property name The name of the neptune parameter.
 * @property value The value of the neptune parameter.
 */
public data class ClusterParameterGroupParameterArgs(
    public val applyMethod: Output<String>? = null,
    public val name: Output<String>,
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.neptune.inputs.ClusterParameterGroupParameterArgs> {
    override fun toJava(): com.pulumi.aws.neptune.inputs.ClusterParameterGroupParameterArgs =
        com.pulumi.aws.neptune.inputs.ClusterParameterGroupParameterArgs.builder()
            .applyMethod(applyMethod?.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ClusterParameterGroupParameterArgs].
 */
@PulumiTagMarker
public class ClusterParameterGroupParameterArgsBuilder internal constructor() {
    private var applyMethod: Output<String>? = null

    private var name: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value Valid values are `immediate` and `pending-reboot`. Defaults to `pending-reboot`.
     */
    @JvmName("mpwubuqafywirbco")
    public suspend fun applyMethod(`value`: Output<String>) {
        this.applyMethod = value
    }

    /**
     * @param value The name of the neptune parameter.
     */
    @JvmName("mqayihptegqhgurd")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The value of the neptune parameter.
     */
    @JvmName("higuajryerrllvye")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value Valid values are `immediate` and `pending-reboot`. Defaults to `pending-reboot`.
     */
    @JvmName("fxsjqtjkuqggarbr")
    public suspend fun applyMethod(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.applyMethod = mapped
    }

    /**
     * @param value The name of the neptune parameter.
     */
    @JvmName("mrcqwyhbhkqsswar")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The value of the neptune parameter.
     */
    @JvmName("qrcfbssyrnwkaaqq")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): ClusterParameterGroupParameterArgs = ClusterParameterGroupParameterArgs(
        applyMethod = applyMethod,
        name = name ?: throw PulumiNullFieldException("name"),
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/neptune/kotlin/inputs/ClusterParameterGroupParameterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.neptune.kotlin.inputs

import com.pulumi.aws.neptune.inputs.ClusterParameterGroupParameterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property applyMethod Valid values are `immediate` and `pending-reboot`. Defaults to `pending-reboot`.
 * @property name The name of the neptune parameter.
 * @property value The value of the neptune parameter.
 */
public data class ClusterParameterGroupParameterArgs(
    public val applyMethod: Output<String>? = null,
    public val name: Output<String>,
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.neptune.inputs.ClusterParameterGroupParameterArgs> {
    override fun toJava(): com.pulumi.aws.neptune.inputs.ClusterParameterGroupParameterArgs =
        com.pulumi.aws.neptune.inputs.ClusterParameterGroupParameterArgs.builder()
            .applyMethod(applyMethod?.applyValue({ args0 -> args0 }))
            .name(name.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ClusterParameterGroupParameterArgs].
 */
@PulumiTagMarker
public class ClusterParameterGroupParameterArgsBuilder internal constructor() {
    private var applyMethod: Output<String>? = null

    private var name: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value Valid values are `immediate` and `pending-reboot`. Defaults to `pending-reboot`.
     */
    @JvmName("cqcufoiiqqrfblqy")
    public suspend fun applyMethod(`value`: Output<String>) {
        this.applyMethod = value
    }

    /**
     * @param value The name of the neptune parameter.
     */
    @JvmName("gyyqxmmctpxyakvk")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The value of the neptune parameter.
     */
    @JvmName("jwemoifmyvfdmbuj")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value Valid values are `immediate` and `pending-reboot`. Defaults to `pending-reboot`.
     */
    @JvmName("lbnawdsjmpowotgr")
    public suspend fun applyMethod(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.applyMethod = mapped
    }

    /**
     * @param value The name of the neptune parameter.
     */
    @JvmName("ymicsekaailteofu")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The value of the neptune parameter.
     */
    @JvmName("dnecdirtwyaryjwf")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): ClusterParameterGroupParameterArgs = ClusterParameterGroupParameterArgs(
        applyMethod = applyMethod,
        name = name ?: throw PulumiNullFieldException("name"),
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}
